use dir_odt_to_pdf::directory_processor::DirectoryProcessor;
use std::fs;
use std::path::PathBuf;
use tempfile::TempDir;

#[test]
fn test_needs_processing() {
    let temp_dir = TempDir::new().unwrap();
    let source = temp_dir.path().join("source.txt");
    let dest = temp_dir.path().join("dest.txt");

    // Test non-existent destination
    assert!(DirectoryProcessor::needs_processing(&source, &dest));

    // Create files and test modification times
    fs::write(&source, "test").unwrap();
    fs::write(&dest, "test").unwrap();

    // Files created very close together should not need copying
    assert!(!DirectoryProcessor::needs_processing(&source, &dest));
}

#[test]
fn test_new_processor() {
    let source = PathBuf::from("/source");
    let target = PathBuf::from("/target");
    let processor = DirectoryProcessor::new(source.clone(), target.clone());

    assert_eq!(processor.source_dir, source);
    assert_eq!(processor.target_dir, target);
    assert!(processor.source_files.is_empty());
}
